@@ -30,9 +30,7 @@ namespace actions {
 
 bool Log::evaluate(Rule *rule, Transaction *transaction,
     std::shared_ptr<RuleMessage> rm) {
-#ifndef NO_LOGS
-    transaction->debug(9, "Saving transaction to logs");
-#endif
+    ms_dbg_a(transaction, 9, "Saving transaction to logs");
     rm->m_saveMessage = true;
     return true;
 }
