@@ -14,8 +14,11 @@
  */
 
 #include <string>
+#include <utility>
+#include <memory>
 
 #include "modsecurity/actions/action.h"
+#include "src/run_time_string.h"
 
 #ifndef SRC_ACTIONS_SET_SID_H_
 #define SRC_ACTIONS_SET_SID_H_
@@ -32,11 +35,15 @@ class SetSID : public Action {
     explicit SetSID(std::string _action)
         : Action(_action) { }
 
+    explicit SetSID(std::unique_ptr<RunTimeString> z)
+        : Action("setsid", RunTimeOnlyIfMatchKind),
+            m_string(std::move(z)) { }
+
     bool evaluate(Rule *rule, Transaction *transaction) override;
     bool init(std::string *error) override;
 
  private:
-    std::string m_collection_key;
+    std::unique_ptr<RunTimeString> m_string;
 };
 
 
