@@ -15,8 +15,10 @@
 
 #include <string>
 #include <memory>
+#include <utility>
 
 #include "modsecurity/actions/action.h"
+#include "src/run_time_string.h"
 
 #ifndef SRC_ACTIONS_TAG_H_
 #define SRC_ACTIONS_TAG_H_
@@ -30,13 +32,17 @@ namespace actions {
 
 class Tag : public Action {
  public:
-    explicit Tag(std::string action)
-        : Action(action, RunTimeOnlyIfMatchKind) { }
+    explicit Tag(std::unique_ptr<RunTimeString> z)
+        : Action("tag", RunTimeOnlyIfMatchKind),
+        m_string(std::move(z)) { }
 
     std::string getName(Transaction *transaction);
 
     bool evaluate(Rule *rule, Transaction *transaction,
         std::shared_ptr<RuleMessage> rm) override;
+
+ protected:
+    std::unique_ptr<RunTimeString> m_string;
 };
 
 
