@@ -82,7 +82,7 @@ bool Lua::load(std::string script, std::string *err) {
         return false;
     }
 
-#ifdef WITH_LUA_5_2
+#if defined (WITH_LUA_5_2) || defined (WITH_LUA_5_1)
     if (lua_dump(L, Lua::blob_keeper, reinterpret_cast<void *>(&m_blob))) {
 #else
     if (lua_dump(L, Lua::blob_keeper, reinterpret_cast<void *>(&m_blob), 0)) {
@@ -138,8 +138,12 @@ int Lua::run(Transaction *t) {
     luaL_setfuncs(L, mscLuaLib, 0);
     lua_setglobal(L, "m");
 
+#ifdef WITH_LUA_5_1
+    int rc = lua_load(L, Lua::blob_reader, &m_blob, m_scriptName.c_str());
+#else
     int rc = lua_load(L, Lua::blob_reader, &m_blob, m_scriptName.c_str(),
         NULL);
+#endif
     if (rc != LUA_OK) {
         std::string e;
         e.assign("Failed to execute lua script: " + m_scriptName + ". ");
@@ -150,14 +154,14 @@ int Lua::run(Transaction *t) {
             case LUA_ERRMEM:
                 e.assign("Memory error. ");
                 break;
+#ifndef WITH_LUA_5_1
             case LUA_ERRGCMM:
                 e.assign("Garbage Collector error. ");
                 break;
+#endif
         }
         e.append(lua_tostring(L, -1));
-#ifndef NO_LOGS
-        t->debug(2, e);
-#endif
+        ms_dbg_a(t, 2, e);
         ret = false;
         goto err;
     }
@@ -171,9 +175,8 @@ int Lua::run(Transaction *t) {
             e.append(" - ");
             e.append(luaerr);
         }
-#ifndef NO_LOGS
-        t->debug(2, e);
-#endif
+        ms_dbg_a(t, 2, e);
+
         ret = false;
         goto err;
     }
@@ -189,9 +192,8 @@ int Lua::run(Transaction *t) {
             e.append(" - ");
             e.append(luaerr);
         }
-#ifndef NO_LOGS
-        t->debug(2, e);
-#endif
+        ms_dbg_a(t, 2, e);
+
         ret = false;
         goto err;
     }
@@ -200,9 +202,8 @@ int Lua::run(Transaction *t) {
     if (a != NULL) {
         luaRet.assign(a);
     }
-#ifndef NO_LOGS
-    t->debug(9, "Returning from lua script: " + luaRet);
-#endif
+
+    ms_dbg_a(t, 9, "Returning from lua script: " + luaRet);
 
     if (luaRet.size() == 0) {
         ret = false;
@@ -215,9 +216,8 @@ err:
 
     return ret;
 #else
-#ifndef NO_LOGS
-    t->debug(9, "Lua support was not enabled.");
-#endif
+    ms_dbg_a(t, 9, "Lua support was not enabled.");
+
     return false;
 #endif
 }
@@ -239,9 +239,7 @@ int Lua::log(lua_State *L) {
 
     /* Log message. */
     if (t != NULL) {
-#ifndef NO_LOGS
-        t->debug(level, text);
-#endif
+        ms_dbg_a(t, level, text);
     }
 
     return 0;
@@ -333,9 +331,8 @@ int Lua::setvar(lua_State *L) {
 
 
     if (nargs != 2) {
-#ifndef NO_LOGS
-        t->debug(8, "m.setvar: Failed m.setvar funtion must has 2 arguments");
-#endif
+        ms_dbg_a(t, 8,
+            "m.setvar: Failed m.setvar funtion must has 2 arguments");
         return -1;
     }
     var_value = luaL_checkstring(L, 2);
@@ -356,38 +353,49 @@ int Lua::setvar(lua_State *L) {
             std::string::npos);
 
     } else {
-#ifndef NO_LOGS
-        t->debug(8, "m.setvar: Must specify a collection using dot character" \
+        ms_dbg_a(t, 8,
+            "m.setvar: Must specify a collection using dot character" \
             " - ie m.setvar(tx.myvar,mydata)");
-#endif
         return -1;
     }
 
     if (collection == "TX") {
         t->m_collections.m_tx_collection->storeOrUpdateFirst(
-            "TX:" + variableName, "", var_value);
+            variableName,
+            var_value);
     }
     else if (collection == "IP") {
         t->m_collections.m_ip_collection->storeOrUpdateFirst(
-            "IP:" + variableName, t->m_collections.m_ip_collection_key,
+            variableName, t->m_collections.m_ip_collection_key,
+            t->m_rules->m_secWebAppId.m_value,
             var_value);
     }
     else if (collection == "GLOBAL") {
         t->m_collections.m_global_collection->storeOrUpdateFirst(
-            "GLOBAL:" + variableName, t->m_collections.m_global_collection_key,
+            variableName, t->m_collections.m_global_collection_key,
+            t->m_rules->m_secWebAppId.m_value,
             var_value);
     }
     else if (collection == "RESOURCE") {
         t->m_collections.m_resource_collection->storeOrUpdateFirst(
-            "RESOURCE:" + variableName,
-            t->m_collections.m_resource_collection_key, var_value);
+            variableName,
+            t->m_collections.m_resource_collection_key, 
+            t->m_rules->m_secWebAppId.m_value,
+            var_value);
     }
     else if (collection == "SESSION") {
          t->m_collections.m_session_collection->storeOrUpdateFirst(
-            "SESSION:" + variableName, t->m_collections.m_session_collection_key,
+            variableName, t->m_collections.m_session_collection_key,
+                    t->m_rules->m_secWebAppId.m_value,
             var_value);
     }
+    else if (collection == "USER") {
+        t->m_collections.m_user_collection->storeOrUpdateFirst(
+            variableName, t->m_collections.m_user_collection_key,
+                    t->m_rules->m_secWebAppId.m_value,
+            var_value);
 
+    }
     return 0;
 }
 
@@ -402,7 +410,11 @@ std::string Lua::applyTransformations(lua_State *L, Transaction *t,
 
     if (lua_istable(L, idx)) {
         const char *name = NULL;
+#ifdef WITH_LUA_5_1
+        int i, n = lua_objlen(L, idx);
+#else
         int i, n = lua_rawlen(L, idx);
+#endif
 
         for (i = 1; i <= n; i++) {
             lua_rawgeti(L, idx, i);
@@ -421,10 +433,9 @@ std::string Lua::applyTransformations(lua_State *L, Transaction *t,
             if (tfn) {
                 newVar = tfn->evaluate(newVar, t);
             } else {
-#ifndef NO_LOGS
-                t->debug(1, "SecRuleScript: Invalid transformation function: " \
+                ms_dbg_a(t, 1,
+                    "SecRuleScript: Invalid transformation function: " \
                     + std::string(name));
-#endif
             }
             delete tfn;
         }
@@ -445,19 +456,15 @@ std::string Lua::applyTransformations(lua_State *L, Transaction *t,
             newVar = tfn->evaluate(newVar, t);
             delete tfn;
         } else {
-#ifndef NO_LOGS
-            t->debug(1, "SecRuleScript: Invalid transformation function: " \
+            ms_dbg_a(t, 1, "SecRuleScript: Invalid transformation function: " \
                 + std::string(name));
-#endif
         }
         return newVar;
     }
-#ifndef NO_LOGS
-    t->debug(8, "SecRuleScript: Transformation parameter must be a " \
+    ms_dbg_a(t, 8, "SecRuleScript: Transformation parameter must be a " \
         "transformation name or array of transformation names, but found " \
         "" + std::string(lua_typename(L, idx)) + " (type " \
         + std::to_string(lua_type(L, idx)) + ")");
-#endif
     return newVar;
 }
 #endif
