@@ -63,16 +63,18 @@ ModSecurity::ModSecurity()
     : m_connector(""),
     m_whoami(""),
 #ifdef WITH_LMDB
-    m_global_collection(new collection::backend::LMDB()),
-    m_resource_collection(new collection::backend::LMDB()),
-    m_ip_collection(new collection::backend::LMDB()),
-    m_session_collection(new collection::backend::LMDB()),
-    m_user_collection(new collection::backend::LMDB()),
+    m_global_collection(new collection::backend::LMDB("GLOBAL")),
+    m_resource_collection(new collection::backend::LMDB("RESOURCE")),
+    m_ip_collection(new collection::backend::LMDB("IP")),
+    m_session_collection(new collection::backend::LMDB("SESSION")),
+    m_user_collection(new collection::backend::LMDB("USER")),
 #else
     m_global_collection(new collection::backend::InMemoryPerProcess("GLOBAL")),
     m_ip_collection(new collection::backend::InMemoryPerProcess("IP")),
-    m_resource_collection(new collection::backend::InMemoryPerProcess("RESOURCE")),
-    m_session_collection(new collection::backend::InMemoryPerProcess("SESSION")),
+    m_resource_collection(
+        new collection::backend::InMemoryPerProcess("RESOURCE")),
+    m_session_collection(
+        new collection::backend::InMemoryPerProcess("SESSION")),
     m_user_collection(new collection::backend::InMemoryPerProcess("USER")),
 #endif
     m_logCb(NULL) {
@@ -196,10 +198,9 @@ void ModSecurity::serverLog(void *data, std::shared_ptr<RuleMessage> rm) {
     }
 
     if (m_logProperties & TextLogProperty) {
-        char *d = strdup(rm->log().c_str());
-        const void *a = static_cast<const void *>(d);
+        std::string &&d = rm->log();
+        const void *a = static_cast<const void *>(d.c_str());
         m_logCb(data, a);
-        free(d);
         return;
     }
 
@@ -221,7 +222,6 @@ int ModSecurity::processContentOffset(const char *content, size_t len,
     Utils::Regex variables("v([0-9]+),([0-9]+)");
     Utils::Regex operators("o([0-9]+),([0-9]+)");
     Utils::Regex transformations("t:(?:(?!t:).)+");
-    int i;
     yajl_gen g;
     std::string varValue;
     std::string opValue;
@@ -326,6 +326,8 @@ int ModSecurity::processContentOffset(const char *content, size_t len,
             varValue.c_str()),
             varValue.size());
         yajl_gen_map_close(g);
+
+        delete t;
     }
 
     yajl_gen_array_close(g);
