@@ -18,13 +18,12 @@
 #include <string>
 
 #include "src/operators/operator.h"
-#include "src/macro_expansion.h"
 
 namespace modsecurity {
 namespace operators {
 
 bool Lt::evaluate(Transaction *transaction, const std::string &input) {
-    std::string p = MacroExpansion::expand(m_param, transaction);
+    std::string p(m_string->evaluate(transaction));
 
     bool lt = atoll(input.c_str()) < atoll(p.c_str());
 
