@@ -13,12 +13,13 @@
  *
  */
 
-#include <vector>
-#include <string>
-#include <list>
-#include <utility>
-#include <memory>
 #include <exception>
+#include <list>
+#include <memory>
+#include <string>
+#include <utility>
+#include <vector>
+#include <deque>
 
 #include "modsecurity/transaction.h"
 #include "modsecurity/rule.h"
@@ -29,23 +30,139 @@
 #ifndef SRC_VARIABLES_VARIABLE_H_
 #define SRC_VARIABLES_VARIABLE_H_
 
+#define DEFINE_VARIABLE(n, N, e) \
+    VAR_DIRECT(n, N, e)
+
+#define DEFINE_VARIABLE_DICT(n, N, e) \
+    VAR_WITH_DICT_ELEMENT(n, N, e) \
+    \
+    VAR_WITHOUT_DICT_ELEMENT(n, N, e) \
+    \
+    VAR_WITH_REGEX(n, N, e) \
+
+
+
+#define VAR_WITH_REGEX(n, N, e) \
+class n ## _DictElementRegexp : public VariableRegex { \
+ public: \
+    explicit n ## _DictElementRegexp(std::string regex) \
+        : VariableRegex(#N, regex) { } \
+\
+    void evaluate(Transaction *transaction, \
+        Rule *rule, \
+        std::vector<const VariableValue *> *l) override { \
+        transaction-> e .resolveRegularExpression(&m_r, l, \
+            m_keyExclusion); \
+    } \
+};
+
+
+#define VAR_WITH_DICT_ELEMENT(n, N, e) \
+class n ## _DictElement : public VariableDictElement { \
+ public: \
+    explicit n ## _DictElement(std::string dictElement) \
+        : VariableDictElement(#N, dictElement) { } \
+\
+    void evaluate(Transaction *transaction, \
+        Rule *rule, \
+        std::vector<const VariableValue *> *l) override { \
+        transaction-> e .resolve(m_dictElement, l); \
+    } \
+};
+
+
+#define VAR_WITHOUT_DICT_ELEMENT(n, N, e) \
+class n ## _NoDictElement : public Variable { \
+ public: \
+    explicit n ## _NoDictElement() \
+        : Variable(#N) { } \
+\
+    void evaluate(Transaction *transaction, \
+        Rule *rule, \
+        std::vector<const VariableValue *> *l) override { \
+        transaction-> e .resolve(l, m_keyExclusion); \
+    } \
+};
+
+
+#define VAR_DIRECT(n, N, e) \
+class n : public Variable { \
+ public: \
+    n() \
+        : Variable(#N) { } \
+    \
+    void evaluate(Transaction *transaction, \
+        Rule *rule, \
+        std::vector<const VariableValue *> *l) override { \
+        transaction-> e .evaluate(l); \
+    } \
+};
+
+
 namespace modsecurity {
 
 class Transaction;
 namespace Variables {
 
-
-class Variable {
+class KeyExclusion {
  public:
-    explicit Variable(std::string _name);
-    virtual ~Variable() { }
+    virtual bool match(std::string &a) = 0;
+    virtual ~KeyExclusion() { }
+};
 
-    virtual void evaluate(Transaction *t,
-        Rule *rule,
-        std::vector<const VariableValue *> *l) = 0;
 
-    static std::string to_s(std::vector<Variable *> *variables);
+// FIXME: use pre built regex.
+class KeyExclusionRegex : public KeyExclusion {
+ public:
+    explicit KeyExclusionRegex(Utils::Regex re)
+        : m_re(re.pattern) { }
+    explicit KeyExclusionRegex(std::string re)
+        : m_re(re) { }
 
+    ~KeyExclusionRegex() override { }
+
+    bool match(std::string &a) override {
+        return m_re.searchAll(a).size() > 0;
+    }
+
+    Utils::Regex m_re;
+};
+
+
+class KeyExclusionString : public KeyExclusion {
+ public:
+    KeyExclusionString(std::string &a)
+        : m_key(utils::string::toupper(a)) { }
+
+    ~KeyExclusionString() override { }
+
+    bool match(std::string &a) override {
+        return a.size() == m_key.size() && std::equal(a.begin(), a.end(),
+            m_key.begin(),
+            [](char aa, char bb) {
+                return static_cast<char>(toupper(aa)) == static_cast<char>(bb);
+            });
+    }
+
+    std::string m_key;
+};
+
+
+class KeyExclusions : public std::deque<std::unique_ptr<KeyExclusion>> {
+ public:
+    bool toOmit(std::string a) {
+        for (auto &z : *this) {
+            if (z->match(a)) {
+                return true;
+            }
+        }
+        return false;
+    }
+};
+
+
+class VariableMonkeyResolution {
+ public:
     static inline bool comp(const std::string &a, const std::string &b) {
         return a.size() == b.size()
              && std::equal(a.begin(), a.end(), b.begin(),
@@ -175,8 +292,6 @@ class Variable {
                 t->m_variableArgsGetNames.resolve(var, l);
             } else if (comp(variable, "ARGS_POST_NAMES")) {
                 t->m_variableArgsPostNames.resolve(var, l);
-            } else if (comp(col, "RULE")) {
-                t->m_variableRule.resolve(var, l);
             } else if (comp(col, "ARGS_GET")) {
                 t->m_variableArgsGet.resolve(var, l);
             } else if (comp(col, "ARGS_POST")) {
@@ -357,8 +472,6 @@ class Variable {
                 vv = t->m_variableArgsGetNames.resolveFirst(var);
             } else if (comp(variable, "ARGS_POST_NAMES")) {
                 vv = t->m_variableArgsPostNames.resolveFirst(var);
-            } else if (comp(col, "RULE")) {
-                vv = t->m_variableRule.resolveFirst(var);
             } else if (comp(col, "ARGS_GET")) {
                 vv = t->m_variableArgsGet.resolveFirst(var);
             } else if (comp(col, "ARGS_POST")) {
@@ -421,40 +534,107 @@ class Variable {
         }
         return std::string(*vv.get());
     }
+};
+
+
+class Variable : public VariableMonkeyResolution {
+ public:
+    explicit Variable(std::string _name);
+    explicit Variable(Variable *_name);
+    virtual ~Variable() { }
+
+
+    virtual void evaluate(Transaction *t,
+        Rule *rule,
+        std::vector<const VariableValue *> *l) = 0;
+
+
+    bool inline belongsToCollection(Variable *var) {
+        return m_collectionName.size() == var->m_collectionName.size()
+             && std::equal(m_collectionName.begin(), m_collectionName.end(),
+                           var->m_collectionName.begin(),
+            [](char aa, char bb) {
+            return toupper(aa) == bb;
+        });
+    }
+
+
+    void addsKeyExclusion(Variable *v);
+
+
+    bool operator==(const Variable& b) {
+        return m_collectionName == b.m_collectionName &&
+            m_name == b.m_name &&
+            *m_fullName == *b.m_fullName;
+    }
+
+
+    std::string& operator+=(const char * p) {  return m_name; }
+
 
     std::string m_name;
     std::string m_collectionName;
     std::shared_ptr<std::string> m_fullName;
+    KeyExclusions m_keyExclusion;
+};
 
-    bool m_isExclusion;
-    bool m_isCount;
+class VariableDictElement : public Variable {
+ public:
+    VariableDictElement(std::string name, std::string dict_element)
+        :  m_dictElement(dict_element), Variable(name + ":" + dict_element) { }
+
+    std::string m_dictElement;
+};
+
+
+class VariableRegex : public Variable {
+ public:
+    VariableRegex(std::string name, std::string regex)
+        :  m_r(regex),
+        m_regex(regex),
+        Variable(name + ":" + "regex(" + regex + ")") { }
+
+    // FIXME: no need for that.
+    std::string m_regex;
+    Utils::Regex m_r;
+};
+
+class Variables : public std::vector<Variable *> {
+ public:
+    bool contains(Variable *v) {
+        return std::find_if(begin(), end(),
+            [v](Variable *m) -> bool { return *v == *m; }) != end();
+    };
+    bool contains(const std::string &v) {
+        return std::find_if(begin(), end(),
+            [v](Variable *m) -> bool {
+                return v == *m->m_fullName.get();
+            }) != end();
+    };
 };
 
 
 class VariableModificatorExclusion : public Variable {
  public:
     explicit VariableModificatorExclusion(std::unique_ptr<Variable> var)
-        : Variable(*var->m_fullName.get()),
-        m_var(std::move(var)) {
-            m_isExclusion = true;
-        }
+        : m_base(std::move(var)), Variable(var.get()) { }
 
     void evaluate(Transaction *t,
         Rule *rule,
         std::vector<const VariableValue *> *l) {
-        m_var->evaluate(t, rule, l);
+        m_base->evaluate(t, rule, l);
     }
 
-    std::unique_ptr<Variable> m_var;
+    std::unique_ptr<Variable> m_base;
 };
 
 
 class VariableModificatorCount : public Variable {
  public:
     explicit VariableModificatorCount(std::unique_ptr<Variable> var)
-        : Variable(*var->m_fullName.get()),
-        m_var(std::move(var)) {
-            m_isCount = true;
+        : Variable(var.get()),
+          m_base(nullptr) {
+            m_base.reset(var.release());
         }
 
     void evaluate(Transaction *t,
@@ -464,7 +644,8 @@ class VariableModificatorCount : public Variable {
         VariableValue *val = NULL;
         int count = 0;
 
-        m_var->evaluate(t, rule, &reslIn);
+        m_base->evaluate(t, rule, &reslIn);
+
         for (const VariableValue *a : reslIn) {
             count++;
             delete a;
@@ -473,16 +654,21 @@ class VariableModificatorCount : public Variable {
         reslIn.clear();
 
         std::string *res = new std::string(std::to_string(count));
-        val = new VariableValue(m_var->m_fullName, res);
+        val = new VariableValue(m_fullName, res);
         delete res;
 
         l->push_back(val);
         return;
     }
 
-    std::unique_ptr<Variable> m_var;
+    std::unique_ptr<Variable> m_base;
 };
 
+
+std::string operator+(std::string a, modsecurity::Variables::Variable *v);
+std::string operator+(std::string a, modsecurity::Variables::Variables *v);
+
+
 }  // namespace Variables
 }  // namespace modsecurity
 
