@@ -37,10 +37,10 @@ class WebAppId : public Variable {
 
     void evaluate(Transaction *transaction,
         Rule *rule,
-        std::vector<const collection::Variable *> *l) override {
+        std::vector<const VariableValue *> *l) override {
         const std::string name("WEBAPPID");
         const std::string rname = transaction->m_rules->m_secWebAppId.m_value;
-        l->push_back(new collection::Variable(&m_name, &rname));
+        l->push_back(new VariableValue(&m_name, &rname));
     }
 };
 
